@@ -26,7 +26,7 @@
 #ifdef HAVE_SYS_RESOURCE_H
 #include <sys/resource.h>
 #endif
-#include <locale.h>
+//#include <locale.h>
 
 typedef void (void_main_proc_t)(int, char **);
 
@@ -121,7 +121,16 @@ inner_main(void * closure, int argc, char ** argv)
 int
 main(int argc, char ** argv)
 {
-    setlocale(LC_ALL, "");
+    {
+        char const * lc = getenv("LC_ALL");
+        if ((lc != NULL) && (*lc != NUL) && (strcmp(lc, "C") != 0)) {
+            putenv("LC_ALL=C");
+            execvp(argv[0], argv);
+            fserr(AUTOGEN_EXIT_FS_ERROR, "execvp", argv[0]);
+        }
+    }
+
+    // setlocale(LC_ALL, "");
     setup_signals(ignore_signal, SIG_DFL, catch_sig_and_bail);
     optionSaveState(&autogenOptions);
     trace_fp = stderr;
@@ -129,7 +138,7 @@ main(int argc, char ** argv)
 
     AG_SCM_BOOT_GUILE(argc, argv, inner_main);
 
-    /* NOT REACHED */
+    /* NOTREACHED */
     return EXIT_FAILURE;
 }
 
@@ -346,9 +355,6 @@ done_check(void)
             oops_pfx = zNil;
         }
 
-        if (OPT_VALUE_TRACE > TRACE_NOTHING)
-            scm_backtrace();
-
         fprintf(stderr, SCHEME_EVAL_ERR_FMT, current_tpl->td_file,
                 cur_macro->md_line);
 
@@ -569,17 +575,6 @@ setup_signals(sighandler_proc_t * hdl_chld,
             sa.sa_handler = SIG_IGN;
             break;
 
-#ifdef DAEMON_ENABLED
-# error DAEMON-ization of AutoGen is not ready for prime time
-  Choke Me.
-        case SIGHUP:
-            if (HAVE_OPT(DAEMON)) {
-                sa.sa_handler = handleSighup;
-                break;
-            }
-            /* FALLTHROUGH */
-#endif
-
         default:
             sa.sa_handler = hdl_dflt;
         }
