@@ -5,8 +5,12 @@
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
  *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2015 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -35,14 +39,14 @@ KEYWORD_TABLE
 #undef _KW_
 
 #define _KW_(w) z ## w,
-static char const*  apzKeywords[] = { KEYWORD_TABLE };
+static char const * const kword_table[] = { KEYWORD_TABLE };
 #undef _KW_
 
 #define _KW_(w) DP_EV_ ## w,
-te_dp_event aKeywordTkn[] = { KEYWORD_TABLE };
+te_dp_event kword_tkns[] = { KEYWORD_TABLE };
 #undef _KW_
 
-#define KEYWORD_CT  (sizeof(apzKeywords) / sizeof(apzKeywords[0]))
+#define KEYWORD_CT  (sizeof(kword_table) / sizeof(kword_table[0]))
 
 #define ERROR  (-1)
 #define FINISH (-1)
@@ -51,6 +55,9 @@ te_dp_event aKeywordTkn[] = { KEYWORD_TABLE };
 static void
 pop_context(void);
 
+static int
+count_nl(char const * pz);
+
 static void
 trim_whitespace(void);
 
@@ -63,6 +70,9 @@ lex_backquote(void);
 static tSuccess
 lex_comment(void);
 
+static tSuccess
+lex_dollar(void);
+
 static tSuccess
 lex_here_string(void);
 
@@ -72,11 +82,11 @@ loadScheme(void);
 static void
 alist_to_autogen_def(void);
 
-static char*
-gather_name(char * pzScan, te_dp_event * pRetVal);
+static char *
+gather_name(char * scan, te_dp_event * ret_val);
 
-static char*
-build_here_str(char* scan);
+static char *
+build_here_str(char * scan);
 /* = = = END-STATIC-FORWARD = = = */
 
 /**
@@ -85,12 +95,32 @@ build_here_str(char* scan);
 static void
 pop_context(void)
 {
-    scan_ctx_t* pCX = cctx;
+    scan_ctx_t * pCX = cctx;
     cctx          = cctx->scx_next;
     pCX->scx_next = end_ctx;
     end_ctx       = pCX;
 }
 
+/**
+ * Count the newlines in a NUL terminated string
+ */
+static int
+count_nl(char const * pz)
+{
+    int ct = 0;
+    for (;;) {
+        char const * p = strchr(pz, NL);
+        if (p == NULL)
+            break;
+        ct++;
+        pz = p + 1;
+    }
+    return ct;
+}
+
+/**
+ * Remove leading white space from the current scan point.
+ */
 static void
 trim_whitespace(void)
 {
@@ -142,7 +172,7 @@ static tSuccess
 lex_backquote(void)
 {
     int line_no = cctx->scx_line;
-    char* pz = ao_string_cook(cctx->scx_scan, &line_no);
+    char * pz = ao_string_cook(cctx->scx_scan, &line_no);
 
     if (pz == NULL)
         return FAILURE;
@@ -152,7 +182,7 @@ lex_backquote(void)
     cctx->scx_scan = pz;
 
     token_code = DP_EV_STRING;
-    pz = shell_cmd((char const*)token_str);
+    pz = shell_cmd((char const *)token_str);
     cctx->scx_line = line_no;
 
     if (pz == NULL)
@@ -171,9 +201,9 @@ lex_comment(void)
     switch (cctx->scx_scan[1]) {
     case '*':
     {
-        char* pz = strstr(cctx->scx_scan+2, END_C_COMMENT);
+        char * pz = strstr(cctx->scx_scan+2, END_C_COMMENT);
         if (pz != NULL) {
-            char* p = cctx->scx_scan+1;
+            char * p = cctx->scx_scan+1;
             for (;;) {
                 p = strchr(p+1, NL);
                 if ((p == NULL) || (p > pz))
@@ -187,7 +217,7 @@ lex_comment(void)
     }
     case '/':
     {
-        char* pz = strchr(cctx->scx_scan+2, NL);
+        char * pz = strchr(cctx->scx_scan+2, NL);
         if (pz != NULL) {
             cctx->scx_scan = pz+1;
             cctx->scx_line++;
@@ -200,10 +230,64 @@ lex_comment(void)
     return FAILURE;
 }
 
+/**
+ * process a dollar character introduced value.
+ *
+ * '$(<...)' load a file that must be there.
+ * '$(?...)' load a file that may be there. If not there, then delete
+ *           the named value associated with it.
+ */
+static tSuccess
+lex_dollar(void)
+{
+    char * next;
+
+    /*
+     * First, ensure the string starts with what we recognize
+     */
+    if (cctx->scx_scan[1] != '(')
+        return FAILURE;
+    switch (cctx->scx_scan[2]) {
+    case '<':
+    case '?': break;
+    default: return FAILURE;
+    }
+
+    /*
+     * Find the start and end of the file name and load the file text.
+     */
+    do {
+        char * fns = SPN_WHITESPACE_CHARS(cctx->scx_scan+3);
+        char * fne = strchr(fns, ')');
+        char   svc;
+
+        if (fne == NULL)
+            return FAILURE;
+        next = fne + 1;
+        fne  = SPN_WHITESPACE_BACK(fns, fne-1);
+        svc  = *fne;
+        *fne = NUL;
+        token_str = load_file(fns);
+        *fne = svc;
+        if (token_str == NULL)
+            break;
+        token_code = DP_EV_STRING;
+        cctx->scx_scan = next;
+        return SUCCESS; /* done -- we've loaded the file. */
+    } while (0);
+
+    if (cctx->scx_scan[2] == '<')
+        return FAILURE;
+
+    cctx->scx_scan = next;
+    token_code = DP_EV_DELETE_ENT;
+    return SUCCESS;
+}
+
 static tSuccess
 lex_here_string(void)
 {
-    char* pz;
+    char * pz;
     if (cctx->scx_scan[1] != '<')
         return FAILURE;
 
@@ -230,7 +314,7 @@ yylex(void)
 
     token_code = DP_EV_INVALID;
 
-scanAgain:
+scan_again:
     /*
      *  Start the process of locating a token.
      *  We branch here after skipping over a comment
@@ -249,7 +333,7 @@ scanAgain:
             goto lex_done;
 
         pop_context();
-        goto scanAgain;
+        goto scan_again;
 
     case '#':
     {
@@ -260,7 +344,7 @@ scanAgain:
          *  "cctx" in a register.  It must be reloaded from memory.
          */
         cctx->scx_scan = pz;
-        goto scanAgain;
+        goto scan_again;
     }
 
     case '{': SET_LIT_TKN(O_BRACE);   break;
@@ -274,7 +358,7 @@ scanAgain:
     case '\'':
     case '"':
     {
-        char* pz = ao_string_cook(cctx->scx_scan, &(cctx->scx_line));
+        char * pz = ao_string_cook(cctx->scx_scan, &(cctx->scx_line));
         if (pz == NULL)
             goto NUL_error;
 
@@ -285,10 +369,15 @@ scanAgain:
         break;
     }
 
+    case '$':
+        if (lex_dollar() == SUCCESS)
+            break;
+        goto bad_token;
+        
     case '<':
         switch (lex_here_string()) {
         case SUCCESS: break;
-        case FAILURE: goto BrokenToken;
+        case FAILURE: goto bad_token;
         case PROBLEM: return DP_EV_INVALID;
         }
         break;
@@ -300,7 +389,7 @@ scanAgain:
     case '\\':
         if (strncmp(cctx->scx_scan+1, START_SCHEME_LIST, (size_t)2) == 0) {
             alist_to_autogen_def();
-            goto scanAgain;
+            goto scan_again;
         }
         lex_escaped_char();
         break;
@@ -308,20 +397,18 @@ scanAgain:
     case '`':
         switch (lex_backquote()) {
         case FAILURE: goto NUL_error;
-        case PROBLEM: goto scanAgain;
+        case PROBLEM: goto scan_again;
         case SUCCESS: break;
         }
         break;
 
     case '/':
-        switch (lex_comment()) {
-        case SUCCESS: goto scanAgain;
-        default: break;
-        }
+        if (lex_comment() == SUCCESS)
+            goto scan_again;
         /* FALLTHROUGH */ /* to Invalid input char */
 
     default:
-    BrokenToken:
+    bad_token:
         cctx->scx_scan = gather_name(cctx->scx_scan, &token_code);
         break;
     }   /* switch (*cctx->scx_scan) */
@@ -353,7 +440,7 @@ scanAgain:
 
 
 LOCAL void
-yyerror(char* s)
+yyerror(char * s)
 {
     char * pz;
 
@@ -382,8 +469,8 @@ yyerror(char* s)
 static void
 loadScheme(void)
 {
-    char*    pzText    = cctx->scx_scan;
-    char*    pzEnd     = (char *)skip_scheme(pzText, pzText + strlen(pzText));
+    char *   pzText    = cctx->scx_scan;
+    char *   pzEnd     = (char *)skip_scheme(pzText, pzText + strlen(pzText));
     char     endCh     = *pzEnd;
     int      schemeLen = (int)(pzEnd - pzText);
     int      next_ln;
@@ -434,12 +521,12 @@ loadScheme(void)
 static void
 alist_to_autogen_def(void)
 {
-    char*  pzText  = ++(cctx->scx_scan);
-    char*  pzEnd   = (char *)skip_scheme(pzText, pzText + strlen(pzText));
+    char * pzText  = ++(cctx->scx_scan);
+    char * pzEnd   = (char *)skip_scheme(pzText, pzText + strlen(pzText));
 
     SCM    res;
     size_t res_len;
-    scan_ctx_t*  pCtx;
+    scan_ctx_t * pCtx;
 
     /*
      *  Wrap the scheme expression with the `alist->autogen-def' function
@@ -473,7 +560,7 @@ alist_to_autogen_def(void)
      *  Now, push the resulting string onto the input stack
      *  and link the new scan data into the context stack
      */
-    pCtx = (scan_ctx_t*)AGALOC(sizeof(scan_ctx_t) + 4 + res_len, "lex ctx");
+    pCtx = (scan_ctx_t *)AGALOC(sizeof(scan_ctx_t) + 4 + res_len, "lex ctx");
     pCtx->scx_next = cctx;
     cctx           = pCtx;
 
@@ -484,7 +571,7 @@ alist_to_autogen_def(void)
     pCtx->scx_scan = \
     pCtx->scx_data = (char *)(pCtx + 1);
     pCtx->scx_line = 0;
-    memcpy((void *)(pCtx->scx_scan), (void *)AG_SCM_CHARS(res), res_len);
+    memcpy(VOIDP(pCtx->scx_scan), VOIDP(scm_i_string_chars(res)), res_len);
     pCtx->scx_scan[ res_len ] = NUL;
 
     /*
@@ -496,73 +583,76 @@ alist_to_autogen_def(void)
 }
 
 
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+/**
  *  It may be a number, a name, a keyword or garbage.
  *  Figure out which.
  */
-static char*
-gather_name(char * pzScan, te_dp_event * pRetVal)
+static char *
+gather_name(char * scan, te_dp_event * ret_val)
 {
     /*
-     *  Check for a number.
-     *  Scan it in and advance "pzScan".
+     *  Check for a number.  We don't care about leading zeros, that
+     *  is a user's problem, so no distinction between octal and decimal.
+     *  However, we look for "0x" and "0X" prefixes for hex numbers.
      */
-    if (  IS_DEC_DIGIT_CHAR(*pzScan)
-       || (  (*pzScan == '-')
-          && IS_DEC_DIGIT_CHAR(pzScan[1])
-       )  )  {
-        token_str = pzScan;
-        (void)strtol(pzScan, &pzScan, 0);
-        *pRetVal = DP_EV_NUMBER;
-        return pzScan;
+    if (  IS_DEC_DIGIT_CHAR(*scan)
+       || ((*scan == '-') && IS_DEC_DIGIT_CHAR(scan[1])) ) {
+        token_str = scan;
+        *ret_val  = DP_EV_NUMBER;
+
+        if (  (scan[0] == '0')
+           && ((scan[1] == 'x') || (scan[1] == 'X')) )
+            return SPN_HEX_DIGIT_CHARS(scan + 2);
+
+        return SPN_DEC_DIGIT_CHARS(scan + 1);
     }
 
-    if (! IS_UNQUOTABLE_CHAR(*pzScan))
-        AG_ABEND(aprf(ASSEMBLE_NAME_ERR, ag_pname, *pzScan, cctx->scx_fname,
+    if (! IS_UNQUOTABLE_CHAR(*scan))
+        AG_ABEND(aprf(ASSEMBLE_NAME_ERR, ag_pname, *scan, cctx->scx_fname,
                       cctx->scx_line));
 
     {
-        char* pz = SPN_VALUE_NAME_CHARS(pzScan);
+        char * pz = SPN_VALUE_NAME_CHARS(scan);
 
         if (IS_UNQUOTABLE_CHAR(*pz)) {
-            *pRetVal = DP_EV_OTHER_NAME;
+            *ret_val = DP_EV_OTHER_NAME;
             pz = SPN_UNQUOTABLE_CHARS(pz+1);
 
         } else
-            *pRetVal = DP_EV_VAR_NAME;
+            *ret_val = DP_EV_VAR_NAME;
 
         /*
          *  Return a NAME token, maybe.
          *  If the name is actually a keyword,
          *  we will return that token code instead.
          */
-        token_str = pzScan;
-        pzScan   = (char*)pz;
+        token_str = scan;
+        scan   = (char *)pz;
     }
 
     /*
      *  Now scan the keyword table.
      */
-    if (*pRetVal == DP_EV_VAR_NAME) {
-        char sv_ch = *pzScan;  /* preserve the following character */
+    if (*ret_val == DP_EV_VAR_NAME) {
+        char sv_ch = *scan;  /* preserve the following character */
         int  kw_ix = 0;
-        *pzScan = NUL;         /* NUL terminate the name           */
+        *scan = NUL;         /* NUL terminate the name           */
 
         do  {
-            if (streqvcmp(apzKeywords[ kw_ix ], (char*)token_str) == 0) {
+            if (streqvcmp(kword_table[ kw_ix ], (char *)token_str) == 0) {
                 /*
                  *  Return the keyword token code instead of DP_EV_NAME
                  */
-                *pRetVal = aKeywordTkn[ kw_ix ];
+                *ret_val = kword_tkns[ kw_ix ];
                 break;
             }
         } while (++kw_ix < (int)KEYWORD_CT);
 
-        *pzScan = sv_ch;         /* restore the following character  */
+        *scan = sv_ch;         /* restore the following character  */
     }
 
-    return pzScan;
+    return scan;
 }
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -570,14 +660,14 @@ gather_name(char * pzScan, te_dp_event * pRetVal)
  *  A quoted string has been found.
  *  Find the end of it and compress any escape sequences.
  */
-static char*
-build_here_str(char* scan)
+static char *
+build_here_str(char * scan)
 {
     bool     no_tabs = false;
-    char     zMark[ MAX_HEREMARK_LEN ];
     size_t   markLen = 0;
-    char*    dest;
+    char *   dest;
     int      here_str_line;
+    char     here_mark[MAX_HEREMARK_LEN];
 
     /*
      *  See if we are to strip leading tab chars
@@ -606,12 +696,12 @@ build_here_str(char* scan)
             AG_ABEND(aprf(DEF_ERR_FMT, ag_pname, HERE_MISS_MARK_STR,
                           cctx->scx_fname, cctx->scx_line));
 
-        if (markLen >= sizeof(zMark))
+        if (markLen >= sizeof(here_mark))
             AG_ABEND(aprf(DEF_ERR_FMT, ag_pname, HERE_MARK_TOO_LONG,
                           cctx->scx_fname, cctx->scx_line));
 
-        memcpy(zMark, scan, markLen);
-        zMark[markLen] = NUL;
+        memcpy(here_mark, scan, markLen);
+        here_mark[markLen] = NUL;
     }
 
     token_str = dest = scan;
@@ -634,7 +724,7 @@ build_here_str(char* scan)
     next_line:
         if (no_tabs) {
             while (*scan == TAB)  ++scan;
-            if ((scan[0] == '\\') && (scan[1] == TAB))
+            if ((scan[0] == '\\') && IS_HORIZ_WHITE_CHAR(scan[1]))
                 ++scan;
         }
 
@@ -642,7 +732,7 @@ build_here_str(char* scan)
          *  If we recognize the end mark, break out.
          */
         if (! IS_VARIABLE_NAME_CHAR(scan[markLen]))
-            if (strncmp(scan, zMark, markLen) == 0)
+            if (strncmp(scan, here_mark, markLen) == 0)
                 break;
 
         for (;;) {
@@ -661,13 +751,15 @@ build_here_str(char* scan)
     /*
      *  dest may still equal token_str, if no data were copied
      */
-    if (dest > (char*)token_str)
+    if (dest > (char *)token_str)
          dest[-1] = NUL;
     else dest[0]  = NUL;
 
     return scan + markLen;
 }
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
