@@ -1,11 +1,15 @@
+
 /**
- * \file gdinit.c
- *
- *  getdefs Copyright (C) 1999-2013 by Bruce Korb - all rights reserved
+ *  @file gdinit.c
+ *  @addtogroup columns
+ *  @{
+ */
+/*
+ *  getdefs Copyright (C) 1999-2015 by Bruce Korb - all rights reserved
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
  *
  *  AutoGen is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -24,10 +28,10 @@
 static char const zNoList[] = "ERROR:  block attr must have name list:\n\t%s\n";
 
 /* = = = START-STATIC-FORWARD = = = */
-static char*
-compressOptionText(char* pzS, char* pzE);
+static char *
+compressOptionText(char * pzS, char * pzE);
 
-static char*
+static char *
 fixupSubblockString(char const * pzSrc);
 
 static void
@@ -66,11 +70,11 @@ fserr_die(char const * fmt, ...)
 /*
  *  compressOptionText
  */
-static char*
-compressOptionText(char* pzS, char* pzE)
+static char *
+compressOptionText(char * pzS, char * pzE)
 {
-    char* pzR = pzS;  /* result      */
-    char* pzD = pzS;  /* destination */
+    char * pzR = pzS;  /* result      */
+    char * pzD = pzS;  /* destination */
 
     for (;;) {
         char ch;
@@ -113,7 +117,7 @@ compressOptionText(char* pzS, char* pzE)
 /*
  *  fixupSubblockString
  */
-static char*
+static char *
 fixupSubblockString(char const * pzSrc)
 {
     char *  pzString;
@@ -203,8 +207,8 @@ static void
 loadStdin(void)
 {
     char z[ 4096 ];
-    int    ct  = 0;
-    tCC**  ppz = STACKLST_OPT(INPUT);
+    int  ct  = 0;
+    char const ** ppz = STACKLST_OPT(INPUT);
 
     if (isatty(STDIN_FILENO)) {
         fputs("getdefs error:  no inputs were specified and stdin is a tty\n",
@@ -213,7 +217,7 @@ loadStdin(void)
     }
 
     while (fgets(z, (int)sizeof(z), stdin) != NULL) {
-        char* pz = z + strlen(z);
+        char * pz = z + strlen(z);
 
         if (pz[-1] != '\n') {
             static char const zErr[] =
@@ -245,15 +249,15 @@ loadStdin(void)
  *  option, it will need to be massaged for use.
  */
 LOCAL void
-processEmbeddedOptions(char* pzText)
+processEmbeddedOptions(char * pzText)
 {
     static char const zStStr[] = "/*=--";
     static char const zEndSt[] = "=*/";
 
     for (;;) {
-        char* pzStart = strstr(pzText, zStStr);
-        char* pzEnd;
-        int   sblct = 0;
+        char * pzStart = strstr(pzText, zStStr);
+        char * pzEnd;
+        int    sblct = 0;
 
         if (pzStart == NULL)
             return;
@@ -270,7 +274,7 @@ processEmbeddedOptions(char* pzText)
         optionLoadLine(&getdefsOptions, pzStart);
 
         if (HAVE_OPT(SUBBLOCK) && (sblct != STACKCT_OPT(SUBBLOCK))) {
-            tCC** ppz = STACKLST_OPT(SUBBLOCK);
+            char const ** ppz = STACKLST_OPT(SUBBLOCK);
             ppz[ sblct ] = fixupSubblockString(ppz[sblct]);
         }
         pzText = pzEnd + sizeof(zEndSt);
@@ -324,22 +328,22 @@ set_define_re(void)
      */
     {
         char zRER[MAXNAMELEN];
-        static char const zReErr[] =
+        static char const regex_err[] =
             "Regex error %d (%s):  Cannot compile reg expr:\n\t%s\n";
 
         int rerr = regcomp(&define_re, def_pat, REG_EXTENDED | REG_ICASE);
         if (rerr != 0) {
             regerror(rerr, &define_re, zRER, sizeof(zRER));
-            die(zReErr, rerr, zRER, def_pat);
+            die(regex_err, rerr, zRER, def_pat);
         }
 
         if (free_pat)
-            free((void *)def_pat);
+            free(VOIDP(def_pat));
 
         rerr = regcomp(&attrib_re, zAttribRe, REG_EXTENDED | REG_ICASE);
         if (rerr != 0) {
             regerror(rerr, &attrib_re, zRER, sizeof(zRER));
-            die(zReErr, rerr, zRER, zAttribRe);
+            die(regex_err, rerr, zRER, zAttribRe);
         }
     }
 }
@@ -404,8 +408,8 @@ validateOptions(void)
      *  Prepare each sub-block entry so we can parse easily later.
      */
     if (HAVE_OPT(SUBBLOCK)) {
-        int     ct  = STACKCT_OPT( SUBBLOCK);
-        tCC**   ppz = STACKLST_OPT(SUBBLOCK);
+        int           ct  = STACKCT_OPT( SUBBLOCK);
+        char const ** ppz = STACKLST_OPT(SUBBLOCK);
 
         /*
          *  FOR each SUBBLOCK argument,
@@ -431,7 +435,7 @@ validateOptions(void)
      */
     if (  HAVE_OPT(ORDERING)
        && (OPT_ARG(ORDERING) != NULL)) {
-        static char const zIndexPreamble[] =
+        static char const preamble[] =
             "# -*- buffer-read-only: t -*- vi: set ro:\n"
             "#\n# DO NOT EDIT THIS FILE - it is auto-edited by getdefs\n";
 
@@ -439,7 +443,7 @@ validateOptions(void)
         if (pzIndexText == NULL) {
             pzIndexText = pzEndIndex = pzIndexEOF = malloc((size_t)0x4000);
             indexAlloc = 0x4000;
-            pzEndIndex += sprintf(pzEndIndex, "%s", zIndexPreamble);
+            pzEndIndex += sprintf(pzEndIndex, "%s", preamble);
         } else {
             pzEndIndex = pzIndexEOF = pzIndexText + strlen(pzIndexText);
             indexAlloc = (size_t)(pzEndIndex - pzIndexText) + 1;
@@ -464,24 +468,26 @@ validateOptions(void)
     }
 
     {
-        static char const zAgNameChars[] =
+        static char const ag_nm_chars[] =
             "abcdefghijklmnopqrstuvwxyz"
             "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
             "0123456789" "_-^";
-        static char const zUserNameChs[] = ":.$%*!~<>&@";
-        tCC* p = zAgNameChars;
+        static char const usr_nm_chars[] = ":.$%*!~<>&@";
+
+        char const * p = ag_nm_chars;
 
         while (*p)
-            zUserNameCh[(unsigned)(*p++)] = 3;
+            zUserNameCh[(unsigned char)(*p++)] = 3;
 
-        p = zUserNameChs;
+        p = usr_nm_chars;
         while (*p)
-            zUserNameCh[(unsigned)(*p++)] = 1;
+            zUserNameCh[(unsigned char)(*p++)] = 1;
     }
 }
 
 
-/* emacs
+/** @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
